@@ -1,7 +1,8 @@
 import torch
+from .ActivationFunction import ActivationFunction
 
 
-class Smish(torch.nn.Module):
+class Smish(ActivationFunction):
     def __init__(self):
         super().__init__()
 
