@@ -1,12 +1,13 @@
 import fire
-from .namespaces import MakeNamespace, CacheNamespace
-from .Commands import InitCommand
+from .namespaces import MakeNamespace, CacheNamespace, MediaNamespace
+from .commands import InitCommand
 
 
 class HomaCommand:
     def __init__(self):
         self.make = MakeNamespace()
         self.cache = CacheNamespace()
+        self.media = MediaNamespace()
 
     def init(self):
         InitCommand.run()
