@@ -3,8 +3,8 @@ from .ReportsLogits import ReportsLogits
 
 
 class PredictsProbabilities(ReportsLogits):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
+    def __init__(self):
+        super().__init__()
 
     def predict(self, x: torch.Tensor) -> torch.Tensor:
         logits = self.logits(x)
