@@ -3,8 +3,8 @@ from torch.utils.data import DataLoader
 
 
 class ReportsEnsembleAccuracy:
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
+    def __init__(self):
+        super().__init__()
 
     def accuracy(self, dataloader: DataLoader) -> float:
         predictions, labels = self.metric_necessities(dataloader)
