@@ -1,6 +1,6 @@
 class ReportsEnsembleSize:
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
+    def __init__(self):
+        super().__init__()
 
     @property
     def size(self):
