@@ -3,6 +3,7 @@ import random
 import torch
 from types import SimpleNamespace
 from .Buffer import Buffer
+from ...device import get_device
 
 
 class SoftActorCriticBuffer(Buffer):
@@ -12,26 +13,22 @@ class SoftActorCriticBuffer(Buffer):
     def record(
         self,
         state: numpy.ndarray,
-        action: int,
+        action: numpy.ndarray,
         reward: float,
         next_state: numpy.ndarray,
         termination: float,
-        probability: numpy.ndarray,
     ):
-        self.collection.append(
-            (state, action, reward, next_state, termination, probability)
-        )
+        self.collection.append((state, action, reward, next_state, termination))
 
-    def sample(self, k: int, as_tensor: bool = False):
+    def sample(self, k: int, as_tensor: bool = False, move_to_device: bool = True):
         batch = random.sample(self.collection, k)
-        states, actions, rewards, next_states, terminations, probabilities = zip(*batch)
+        states, actions, rewards, next_states, terminations = zip(*batch)
 
-        states = numpy.array(states)
-        actions = numpy.array(actions)
-        rewards = numpy.array(rewards)
-        next_states = numpy.array(next_states)
-        terminations = numpy.array(terminations)
-        probabilities = numpy.array(probabilities)
+        states = numpy.array(states, dtype=numpy.float32)
+        actions = numpy.array(actions, dtype=numpy.float32)
+        rewards = numpy.array(rewards, dtype=numpy.float32)
+        next_states = numpy.array(next_states, dtype=numpy.float32)
+        terminations = numpy.array(terminations, dtype=numpy.float32)
 
         # add one dimension to both rewards and terminations
         rewards = numpy.expand_dims(rewards, axis=-1)
@@ -43,7 +40,14 @@ class SoftActorCriticBuffer(Buffer):
             rewards = torch.from_numpy(rewards).float()
             next_states = torch.from_numpy(next_states).float()
             terminations = torch.from_numpy(terminations).float()
-            probabilities = torch.from_numpy(probabilities).float()
+
+        if as_tensor and move_to_device:
+            _device = get_device()
+            states = states.to(_device)
+            actions = actions.to(_device)
+            rewards = rewards.to(_device)
+            next_states = next_states.to(_device)
+            terminations = terminations.to(_device)
 
         return SimpleNamespace(
             **{
@@ -52,7 +56,6 @@ class SoftActorCriticBuffer(Buffer):
                 "rewards": rewards,
                 "next_states": next_states,
                 "terminations": terminations,
-                "probabilities": probabilities,
             }
         )
 
